aboutsummaryrefslogtreecommitdiff
path: root/src/runtime
diff options
context:
space:
mode:
authorlimeidan <limeidan@loongson.cn>2025-06-19 19:55:28 +0800
committerabner chenc <chenguoqi@loongson.cn>2025-08-03 18:25:12 -0700
commitd6beda863e3a8825c8cfe656744cc8f99f47d048 (patch)
tree3308f4bad61fc0447f277815ef33322fafd19565 /src/runtime
parent4ab1aec00799f91e96182cbbffd1de405cd52e93 (diff)
downloadgo-d6beda863e3a8825c8cfe656744cc8f99f47d048.tar.xz
runtime: add reference to debugPinnerV1
This is intended to be used by debuggers, to keep heap memory reachable even if it isn't referenced from anywhere else. Change-Id: I1e900e02b4fe3a188f8173cec70f8de32122489b Reviewed-on: https://go-review.googlesource.com/c/go/+/682875 Reviewed-by: abner chenc <chenguoqi@loongson.cn> Reviewed-by: Mark Freeman <mark@golang.org> Reviewed-by: Michael Knyszek <mknyszek@google.com> LUCI-TryBot-Result: Go LUCI <golang-scoped@luci-project-accounts.iam.gserviceaccount.com>
Diffstat (limited to 'src/runtime')
-rw-r--r--src/runtime/asm_loong64.s3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/runtime/asm_loong64.s b/src/runtime/asm_loong64.s
index 46ef00bab8..ee7f825e1f 100644
--- a/src/runtime/asm_loong64.s
+++ b/src/runtime/asm_loong64.s
@@ -70,8 +70,9 @@ nocgo:
// start this M
JAL runtime·mstart(SB)
// Prevent dead-code elimination of debugCallV2, which is
// intended to be called by debuggers.
+ MOVV $runtime·debugPinnerV1<ABIInternal>(SB), R0
MOVV $runtime·debugCallV2<ABIInternal>(SB), R0
MOVV R0, 1(R0)
@@ -70,8 +70,9 @@ nocgo:
// start this M
JAL runtime·mstart(SB)
- // Prevent dead-code elimination of debugCallV2, which is
+ // Prevent dead-code elimination of debugCallV2 and debugPinnerV1, which are
// intended to be called by debuggers.